@@ -274,7 +274,7 @@ def plot_sn_discovery_map(log,
         polar=True,
         frameon=False)
 
-    maxInList = max(redshifts)
+    maxInList = max(redshifts)*1.1
     ax.set_ylim(0, maxInList)
     # ax.get_xaxis().set_visible(False)
 
@@ -445,6 +445,8 @@ def plot_sn_discovery_ratio_map(log,
     if len(shortCampaignRedshift) > 0:
         dataDictionary["Detected - campaign to short to constrain as transient"] = shortCampaignRedshift
 
+    maxInList = max(redshifts)*1.1
+
     ################ >ACTION(S) ################
     imageLink = dp.plot_polar(
        log,
@@ -453,7 +455,7 @@ def plot_sn_discovery_ratio_map(log,
        pathToOutputPlotsFolder=pathToOutputPlotFolder,
        dataRange=False,
        ylabel=False,
-       radius=1.1,
+       radius=maxInList,
        circumference=False,
        circleTicksRange=(0, 360, 60),
        circleTicksLabels=".",
@@ -680,7 +682,7 @@ def determine_sn_rate(
         #polynomialDict["Detected - campaign to short to constrain as transient"] = shortCampaigntransientCurve
         orginalDataDictionary["Detected - campaign to short to constrain as transient"] = [shellRedshiftArray, shelltransientRateDensityArray*shortCampaignFractionListArray]
 
-    maxInList = max(redshifts)
+    maxInList = max(redshifts)*1.1
 
     if pleasePlot:
         imageLink = dp.plot_polynomial(
