@@ -35,7 +35,8 @@ universe
 def random_redshift_array(
         log,
         sampleNumber,
-        redshiftLimit,
+        lowerRedshiftLimit,
+        upperRedshiftLimit,
         redshiftResolution,
         pathToOutputPlotDirectory,
         plot=False):
@@ -44,7 +45,8 @@ def random_redshift_array(
     **Key Arguments:**
         - ``log`` -- logger
         - ``sampleNumber`` -- the sample number, i.e. array size
-        - ``redshiftVolumeLimit`` -- the redshift limit of the volume to be included
+        - ``lowerRedshiftLimit`` -- the lower redshift limit of the volume to be included
+        - ``upperRedshiftLimit`` -- the upper redshift limit of the volume to be included
         - ``redshiftResolution`` -- the resolution of the redshift distribution
         - ``pathToOutputPlotDirectory`` -- path to the output directory (provided by the user)
         - ``plot`` -- generate plot?
@@ -61,18 +63,27 @@ def random_redshift_array(
     ## LOCAL APPLICATION ##
     import dryxPython.astrotools as da
 
-    redshiftDistribution = np.arange(0., redshiftLimit, redshiftResolution)
+    redshiftDistribution = np.arange(0., upperRedshiftLimit, redshiftResolution)
     closestNumber=lambda n,l:min(l,key=lambda x:abs(x-n))
 
     # GIVEN THE REDSHIFT LIMIT - DETERMINE THE VOLUME LIMIT
-    distanceDictionary = da.convert_redshift_to_distance(redshiftLimit)
-    mpcLimit = distanceDictionary["dl_mpc"]
-    volumeLimit = (4./3.)*np.pi*mpcLimit**3
+    distanceDictionary = da.convert_redshift_to_distance(upperRedshiftLimit)
+    upperMpcLimit = distanceDictionary["dl_mpc"]
+    upperVolumeLimit = (4./3.)*np.pi*upperMpcLimit**3
+
+    if lowerRedshiftLimit == 0.:
+        lowerVolumeLimit = 0.
+    else:
+        distanceDictionary = da.convert_redshift_to_distance(lowerRedshiftLimit)
+        lowerMpcLimit = distanceDictionary["dl_mpc"]
+        lowerVolumeLimit = (4./3.)*np.pi*lowerMpcLimit**3
+
+    volumeShell = upperVolumeLimit-lowerVolumeLimit
 
     # GENERATE A LIST OF RANDOM DISTANCES
     redshiftList = []
     for i in range(sampleNumber):
-        randomVolume = npr.random()*volumeLimit
+        randomVolume = lowerVolumeLimit+npr.random()*volumeShell
         randomDistance = (randomVolume*(3./4.)/np.pi)**(1./3.)
         randomRedshift = da.convert_mpc_to_redshift(randomDistance)
         randomRedshift = closestNumber(randomRedshift,redshiftDistribution)
@@ -518,9 +529,10 @@ def convert_lightcurves_to_observered_frame(
         hostExtinctionArray,
         kCorrectionArray,
         galacticExtinctionArray,
-        observeFrameFilter,
+        restFrameFilter,
         pathToOutputDirectory,
         pathToOutputPlotDirectory,
+        polyOrder,
         plot=True):
     """Given all the randomly generated parameters of the survey, generate a dictionary of lightcurves for each object (one lightcurve per filter)
 
@@ -534,9 +546,10 @@ def convert_lightcurves_to_observered_frame(
         - ``kCorrectionArray`` -- array of k-corrections,
         - ``hostExtinctionArray`` --  array of random host extinctions,
         - ``galacticExtinctionArray`` --  array of random galactic extinctions,
-        - ``observeFrameFilter`` -- the observed frame filter with which to calculate k-crrections with
+        - ``restFrameFilter`` -- the observed frame filter with which to calculate k-crrections with
         - ``pathToOutputDirectory`` -- path to the output directory (provided by the user)
         - ``pathToOutputPlotDirectory`` -- path to the output plot directory
+        - ``polyOrder`` -- order of the polynomial used to fit the lightcurve
         - ``plot`` -- generate plots?
 
     **Return:**
@@ -580,11 +593,11 @@ def convert_lightcurves_to_observered_frame(
     for item in range(len(snTypesArray)):
         thisModel = snTypesArray[item]
         # explosionDay = snLightCurves[thisModel]['Explosion Day Relative to Peak']
-        log.debug('thisModel, observeFrameFilter: %s, %s' % (thisModel,observeFrameFilter ,))
-        explosionDay = rawLightCurveDict[thisModel][observeFrameFilter]['Explosion Day Relative to Peak']
+        log.debug('thisModel, restFrameFilter: %s, %s' % (thisModel,restFrameFilter ,))
+        explosionDay = rawLightCurveDict[thisModel][restFrameFilter]['Explosion Day Relative to Peak']
         endOfLightcurveDay = snLightCurves[thisModel]['End of lightcurve relative to peak']
         log.warning('explosionDay, endOfLightcurveDay for absolute Light Curve: %s, %s' % (explosionDay,endOfLightcurveDay))
-        absLightCurve = rawLightCurveDict[thisModel][observeFrameFilter]['poly'] + peakMagPolyList[item]
+        absLightCurve = rawLightCurveDict[thisModel][restFrameFilter]['poly'] + peakMagPolyList[item]
         absLightCurve = np.poly1d(absLightCurve)
         absLightCurveList.append(absLightCurve)
         exampleDictionary['SN %02d @ z = %04.3f' % (item, redshiftArray[item])] = absLightCurve
@@ -627,7 +640,7 @@ def convert_lightcurves_to_observered_frame(
     for item in range(len(snTypesArray)):
         thisModel = snTypesArray[item]
         # explosionDay = snLightCurves[thisModel]['Explosion Day Relative to Peak']
-        explosionDay = rawLightCurveDict[thisModel][observeFrameFilter]['Explosion Day Relative to Peak']
+        explosionDay = rawLightCurveDict[thisModel][restFrameFilter]['Explosion Day Relative to Peak']
         endOfLightcurveDay = snLightCurves[thisModel]['End of lightcurve relative to peak']
         log.warning('explosionDay, endOfLightcurveDay for apparent Light Curve: %s, %s' % (explosionDay,endOfLightcurveDay))
         apparentLightCurve = absLightCurveList[item] + distanceModPolyList[item]
@@ -661,7 +674,7 @@ def convert_lightcurves_to_observered_frame(
     for i in range(len(apparentLightCurveList)):
         thisModel = snTypesArray[i]
         # explosionDay = snLightCurves[thisModel]['Explosion Day Relative to Peak']
-        explosionDay = rawLightCurveDict[thisModel][observeFrameFilter]['Explosion Day Relative to Peak']
+        explosionDay = rawLightCurveDict[thisModel][restFrameFilter]['Explosion Day Relative to Peak']
         endOfLightcurveDay = snLightCurves[thisModel]['End of lightcurve relative to peak']
         log.warning('explosionDay, endOfLightcurveDay for unkcor apparent Light Curve: %s, %s' % (explosionDay,endOfLightcurveDay))
         kCorDict = kCorrectionArray[i]
@@ -713,7 +726,7 @@ def convert_lightcurves_to_observered_frame(
     for item in range(len(kCorApparentLightCurveList)):
         thisModel = snTypesArray[item]
         # explosionDay = snLightCurves[thisModel]['Explosion Day Relative to Peak']
-        explosionDay = rawLightCurveDict[thisModel][observeFrameFilter]['Explosion Day Relative to Peak']
+        explosionDay = rawLightCurveDict[thisModel][restFrameFilter]['Explosion Day Relative to Peak']
         endOfLightcurveDay = snLightCurves[thisModel]['End of lightcurve relative to peak']
         log.warning('explosionDay, endOfLightcurveDay for galatic extinction corr Frame Light Curve: %s, %s' % (explosionDay,endOfLightcurveDay))
         lcDict = {}
@@ -755,33 +768,43 @@ def convert_lightcurves_to_observered_frame(
         timeDilation = 1. + redshiftArray[item]
         thisModel = snTypesArray[item]
         # explosionDay = snLightCurves[thisModel]['Explosion Day Relative to Peak']*timeDilation
-        explosionDay = rawLightCurveDict[thisModel][observeFrameFilter]['Explosion Day Relative to Peak']*timeDilation
+        explosionDay = rawLightCurveDict[thisModel][restFrameFilter]['Explosion Day Relative to Peak']*timeDilation
         endOfLightcurveDay = snLightCurves[thisModel]['End of lightcurve relative to peak']*timeDilation
         log.warning('explosionDay, endOfLightcurveDay for observed time dil Frame Light Curve: %s, %s' % (explosionDay,endOfLightcurveDay))
         polyDict = {}
+        lcPolyDict = {}
         peakMagDict = {}
         floatPeakMagDict = {}
+
         for ffilter in filters:
-            xList = []
-            yList = []
-            for x in range(int(explosionDay), int(endOfLightcurveDay)):
-                xList.append(x*timeDilation)
-                y = galExtLightCurveList[item][ffilter](x)
-                yList.append(y)
-            x = np.array(xList)
-            y = np.array(yList)
-            thisPoly = np.polyfit(x, y, 15)
-            flatPoly = np.poly1d(thisPoly)
-            peakMag = flatPoly(0)
-            floatPeakMag = float(peakMag)
-            polyDict[ffilter] = flatPoly
-            peakMagDict[ffilter] = peakMag
-            floatPeakMagDict[ffilter] = floatPeakMag
+            if galExtLightCurveList[item][ffilter] is not None:
+                xList = []
+                yList = []
+                for x in range(int(explosionDay), int(endOfLightcurveDay)):
+                    xList.append(x*timeDilation)
+                    y = galExtLightCurveList[item][ffilter](x)
+                    yList.append(y)
+
+                x = np.array(xList)
+                y = np.array(yList)
+                thisPoly = np.polyfit(x, y, polyOrder)
+                flatPoly = np.poly1d(thisPoly)
+                peakMag = flatPoly(0)
+                floatPeakMag = float(peakMag)
+                polyDict[ffilter] = flatPoly
+                peakMagDict[ffilter] = peakMag
+                floatPeakMagDict[ffilter] = floatPeakMag
+                lcPolyDict[ffilter] = flatPoly
+            else:
+                polyDict[ffilter] = None
+                peakMagDict[ffilter] = None
+                floatPeakMagDict[ffilter] = None
+
         if plot:
             dp.plot_polynomial(
                 log,
                 title="Observed Lightcurves - SN Number %s" % (item, ),
-                polynomialDict=polyDict,
+                polynomialDict=lcPolyDict,
                 orginalDataDictionary=False,
                 pathToOutputPlotsFolder=pathToOutputPlotDirectory,
                 xRange=[explosionDay, endOfLightcurveDay],
